jactorch.nn.neural\_logic.modules.dimension
===========================================

.. automodule:: jactorch.nn.neural_logic.modules.dimension

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Expander
      Permutation
      Reducer
   
   

   
   
   

   
   
   








.. rubric:: Class Expander
.. autoclass:: Expander
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Permutation
.. autoclass:: Permutation
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Reducer
.. autoclass:: Reducer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







